@@ -184,6 +184,15 @@ GXP[v_قȂ܂B
   \V            (?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x0C\x0A\x0D])
   ---------------------------------------------------------------------------
 
+l \b  \B ߋperlƂ̌݊ۂ߂ɍĒ`Ă܂B
+
+  ---------------------------------------------------------------------------
+  escape        class
+  ---------------------------------------------------------------------------
+  \b            (?:(?:\A|(?<=[\x81-\x9F\xE0-\xFC][\x00-\xFF])|(?<=[^0-9A-Z_a-z]))(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9A-Z_a-z]|\z))
+  \B            (?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?:(?<=[\x81-\x9F\xE0-\xFC][\x00-\xFF])|(?<=[^0-9A-Z_a-z]))(?=[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^0-9A-Z_a-z]))
+  ---------------------------------------------------------------------------
+
 =head1 JPerl ݊̋@\
 
 ȉ̊֐ JPerl Ɠlɋ@\܂B
@@ -471,9 +480,38 @@ oO񍐁Apb`}܂B
     ύXƎ̎sɂ̕ύXf܂Bł /o gƂ $re
     ̓eύXȂł傤AۂɖɂȂ邱Ƃ͂Ȃł傤B
 
-=item * K\̃GXP[v \b  \B
+=item * ϐ $`  $& ͋@\܂
 
-    K\̃GXP[v \b  \B ͊Ғʂ̋@\܂B
+    ȂȂ΁A
+ 
+      'AAABBBCCC' =~ /BBB/;
+ 
+    ƂXNvgXP[vƐK\̐擪Ƀ}`oCgAJ[O
+    ̂߂̋LqǉA
+ 
+      'AAABBBCCC' =~ /\G(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])*?(?:BBB)@Esjis::m_matched/;
+ 
+    ̕ $& Ɋ܂܂Ă܂łB
+    L̎sʂ͈ȉ̂悤ɂȂ܂B 
+      $'  ''       ('AAA' ])
+      $&  'AAABBB' ('BBB' ])
+      $`  'CCC'
+ 
+    @
+    XNvg̋Lq
+ 
+      'AAABBBCCC' =~ /(BBB)/;
+ 
+    ̂悤ɂāAK\Ŝ ( ... ) ň͂ŃLv`܂B
+    GXP[ṽXNvg
+ 
+      'AAABBBCCC' =~ /\G(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])*?(?:(BBB))@Esjis::m_matched/;
+ 
+    ̂悤ɂȂ̂ŁAsA
+ 
+      $1  'BBB'
+ 
+    ɂȂA$& ̑Ɏgp邱Ƃł܂B
 
 =back
 
